@@ -244,6 +244,13 @@ e_name_selector_dialog_class_init (ENameSelectorDialogClass *name_selector_dialo
 
 }
 
+/**
+ * e_name_selector_dialog_new:
+ *
+ * Creates a new #ENameSelectorDialog.
+ *
+ * Return value: A new #ENameSelectorDialog.
+ **/
 ENameSelectorDialog *
 e_name_selector_dialog_new (void)
 {
@@ -846,7 +853,7 @@ contact_column_formatter (GtkTreeViewColumn *column, GtkCellRenderer *cell, GtkT
 	GtkTreeIter    contact_store_iter;
 	GList         *email_list;
 	gchar         *string;
-	gchar         *full_name_str;
+	gchar         *file_as_str;
 	gchar         *email_str;
 	gint           email_n;
 
@@ -857,17 +864,17 @@ contact_column_formatter (GtkTreeViewColumn *column, GtkCellRenderer *cell, GtkT
 	contact = e_contact_store_get_contact (contact_store, &contact_store_iter);
 	email_list = e_contact_get (contact, E_CONTACT_EMAIL);
 	email_str = g_list_nth_data (email_list, email_n);
-	full_name_str = e_contact_get (contact, E_CONTACT_FULL_NAME);
+	file_as_str = e_contact_get (contact, E_CONTACT_FILE_AS);
 
 	if (e_contact_get (contact, E_CONTACT_IS_LIST)) {
-		string = g_strdup_printf ("%s", full_name_str ? full_name_str : "?");
+		string = g_strdup_printf ("%s", file_as_str ? file_as_str : "?");
 	} else {
-		string = g_strdup_printf ("%s%s<%s>", full_name_str ? full_name_str : "",
-					  full_name_str ? " " : "",
+		string = g_strdup_printf ("%s%s<%s>", file_as_str ? file_as_str : "",
+					  file_as_str ? " " : "",
 					  email_str ? email_str : "");
 	}
 
-	g_free (full_name_str);
+	g_free (file_as_str);
 	deep_free_list (email_list);
 
 	g_object_set (cell, "text", string, NULL);
@@ -910,6 +917,14 @@ destination_column_formatter (GtkTreeViewColumn *column, GtkCellRenderer *cell,
  * ENameSelectorDialog API *
  * ----------------------- */
 
+/**
+ * e_name_selector_dialog_peek_model:
+ * @name_selector_dialog: an #ENameSelectorDialog
+ *
+ * Gets the #ENameSelectorModel used by @name_selector_model.
+ *
+ * Return value: The #ENameSelectorModel being used.
+ **/
 ENameSelectorModel *
 e_name_selector_dialog_peek_model (ENameSelectorDialog *name_selector_dialog)
 {
@@ -918,6 +933,13 @@ e_name_selector_dialog_peek_model (ENameSelectorDialog *name_selector_dialog)
 	return name_selector_dialog->name_selector_model;
 }
 
+/**
+ * e_name_selector_dialog_set_model:
+ * @name_selector_dialog: an #ENameSelectorDialog
+ * @model: an #ENameSelectorModel
+ *
+ * Sets the model being used by @name_selector_dialog to @model.
+ **/
 void
 e_name_selector_dialog_set_model (ENameSelectorDialog *name_selector_dialog,
 				  ENameSelectorModel  *model)
